#!/bin/sh
# *******************************************************************************
#  Licensed Materials - Property of IBM
#  © Copyright IBM Corporation 2006, 2015. All Rights Reserved.
#
#  Note to U.S. Government Users Restricted Rights:
#  Use, duplication or disclosure restricted by GSA ADP Schedule
#  Contract with IBM Corp.
#  *******************************************************************************
# NLS_MESSAGEFORMAT_NONE
# NLS_ENCODING=UTF-8


# #############################################################
# #
# # Определите переменные среды, соответствующие параметрам
# # сценария jts_upgrade.sh, и их значения по умолчанию
# #
# #===========================================================
# #
# # Этот файл считывается в начале каждого выполнения сценария
# # jts_upgrade.sh. Для каждого допустимого параметра он
# # инициализирует переменную среды предопределенным
# # значением по умолчанию.
# #
# # Пользователям может потребоваться изменить значение по
# # умолчанию, чтобы запускать jts_upgrade.sh со своими
# # значениями, не вводя параметр и его значение вручную
# # в командной строке.
# #
# # ПРЕДУПРЕЖДЕНИЕ:
# # Для некоторых приложений требуется указывать не все
# # переменные.  Внимательно ознакомьтесь с комментарием
# # перед изменением значения.
# #
# #############################################################

# Параметр: -oldJTSHome
# Формат: -oldJTSHome <путь-к-каталогу>
# Описание:
# 	Полный путь к домашнему каталогу JTS в предыдущей версии.
# Значение по умолчанию:
# 	<нет>
# Ограничения:
#  - <путь-к-каталогу> должен существовать и оканчиваться на 'server/conf'
#  - допустим только для обновления RM и JTS
#
OLD_JTS_HOME=

# Параметр: -jtsContextRoot
# Формат: -jtsContextRoot <корневой-контекст>
# Описание:
# 	Корневой контекст JTS
# Значение по умолчанию:
# 	jts
# Ограничения:
#  - <корневой контекст> должен задавать допустимое краткое имя каталога (без косой черты)
#
JTS_CONTEXT_ROOT=jts

# Параметр: -lpaContextRoot
# Формат: -lpaContextRoot <корневой контекст>
# Описание:
# 	Корневой контекст LPA
# Значение по умолчанию:
# 	admin
# Ограничения:
#  - <корневой контекст> должен задавать допустимое краткое имя каталога (без косой черты)
#
LPA_CONTEXT_ROOT=admin

# Параметр: -oldJTSVersion
# Формат: -oldJTSVersion <версия>
# Описание:
#	 Обновляемая версия JTS.  По умолчанию
# она определяется путем выполнения команды repotools -version для старого экземпляра JTS.
# Значение по умолчанию:
# 	<нет>
# Ограничения:
#  - необходимо указать полную строку версии
#    например: 3.0.0 или 3.0.1
#
OLD_JTS_VERSION=

# Параметр: -updateAppServerFiles
# Формат: -updateAppServerFiles <yes | no>
# Описание:
# 	Следует ли обновлять файлы конфигурации сервера приложений по умолчанию (WebSphere Liberty).
# Значение по умолчанию:
# 	yes
# Ограничения:
#  - Допустимы только значения 'yes' и 'no'
#
UPDATE_APPSERVER_FILES=yes

# Параметр: -updateTomcatFiles
# Формат: -updateTomcatFiles <yes | no>
# Описание:
# 	Разрешает/запрещает обновление файлов конфигурации Tomcat.
# Значение по умолчанию:
# 	no
# Ограничения:
#  - Допустимы только значения 'yes' и 'no'
#
UPDATE_TOMCAT_FILES=no

# Параметр: -oldTomcatHome
# Формат: -oldTomcatHome <путь-к-каталогу>
# Описание:
# 	Полный путь к корневому каталогу Tomcat в старом экземпляре.
# Значение по умолчанию:
# 	<нет>
# Ограничения:
#  - каталог должен существовать
#
OLD_TOMCAT_HOME=

# Параметр: -newJTSHome
# Формат: -newJTSHome <путь-к-каталогу>
# Описание:
# 	Путь к каталогу конфигурации сервера JTS в новой версии.
# Значение по умолчанию:
# 	conf
# Ограничения:
#  - <путь-к-каталогу> должен указывать на существующий каталог,
#    оканчивающийся на 'server/conf'
NEW_JTS_HOME="$START_DIR/conf"

# Параметр: -newTomcatHome
# Формат: -newTomcatHome <путь-к-каталогу>
# Описание:
# 	Путь к домашнему каталогу Tomcat в новой версии.
# Значение по умолчанию:
# 	<нет>
#
NEW_TOMCAT_HOME=

# Параметр: -noPrompt
# Формат: -noPrompt
# Описание:
# 	Не показывать приглашение перед созданием или изменением таблиц
# Значение по умолчанию:
# 	<нет>
# Ограничения:
#  - Допустимо только пустое значение и значение 'noPrompt'
#
# NO_PROMPT=noPrompt
NO_PROMPT=

# Параметр: -noVerify
# Формат: -noVerify
# Описание:
# 	Не выполнять проверку файлов teamserver.properties.
# Значение по умолчанию:
# 	<нет>
# Ограничения:
#  - Допустимо только значение 'noVerify' и пустое значение
#
# NO_VERIFY=noVerify
NO_VERIFY=

# Параметр: -noStepPrompt
# Формат: -noStepPrompt
# Описание:
# 	Не выводить запрос перед выполнением шага.
# Значение по умолчанию:
#   false
# Ограничения:
#  - Допустимы только значения 'true' и 'false'
#
# NO_STEP_PROMPT=true
NO_STEP_PROMPT=false

# Параметр: -noEditor
# Формат: -noEditor
# Описание:
#   Не открывать редактор для файлов teamserver.properties.
# Значение по умолчанию:
#   false
# Ограничения:
#  - Допустимы значения 'true', 'false' и пустое значение
#
# NO_EDITOR=false
NO_EDITOR=false

# Параметр: -noResumePrompt
# Формат: -noResumePrompt
# Описание:
#   Не выводить запрос перед возобновлением шага.
# Значение по умолчанию:
#   false
# Ограничения:
#  - Допустимы только значения 'true' и 'false'
#
# NO_RESUME_PROMPT=false
NO_RESUME_PROMPT=false
