#!/bin/sh
# *******************************************************************************
#  Licensed Materials - Property of IBM
#  (c) Copyright IBM Corporation 2006, 2015. All Rights Reserved.
#
#  Note to U.S. Government Users Restricted Rights:
#  Use, duplication or disclosure restricted by GSA ADP Schedule
#  Contract with IBM Corp.
#  *******************************************************************************
# NLS_MESSAGEFORMAT_NONE
# NLS_ENCODING=UTF-8


# #############################################################
# #
# # Определите переменные среды, соответствующие параметрам
# # сценария rm_upgrade.sh, и их значения по умолчанию
# #
# #===========================================================
# #
# # Этот файл считывается в начале каждого выполнения сценария
# # rm_upgrade.sh. Для каждого допустимого параметра он
# # инициализирует переменную среды предопределенным
# # значением по умолчанию.
# #
# # Пользователям может потребоваться изменить значение по
# # умолчанию, чтобы запускать rm_upgrade.sh со своими
# # значениями, не вводя параметр и его значение вручную
# # в командной строке.
# #
# # ПРЕДУПРЕЖДЕНИЕ:
# # Для некоторых приложений требуется указывать не все
# # переменные.  Внимательно ознакомьтесь с комментарием
# # перед изменением значения.
# #
# #############################################################

# Параметр: -oldApplicationHome
# Формат: -oldApplicationHome <путь-к-каталогу>
# Описание:
# 	Полный путь к домашнему каталогу приложения в старой версии.
# Значение по умолчанию:
# 	<нет>
# Ограничения:
#  - это обязательный параметр
#  - <путь к каталогу> должен задавать существующий каталог и оканчиваться на 'server/conf'
#    например:  /Jazz/IBM/RRC_3.x/jazz/server/conf
#
OLD_APPLICATION_HOME=

# Параметр: -applicationContextRoot
# Формат: -applicationContextRoot <корневой-контекст>
# Описание:
# 	Корневой контекст приложения.
# Значение по умолчанию:
# 	<нет>
# Ограничения:
#  - <корневой-контекст> должен задавать допустимое краткое имя каталога (без косой черты)
#
APPLICATION_CONTEXT_ROOT=

# Параметр: -oldApplicationVersion
# Формат: -oldApplicationVersion <версия>
# Описание:
# Обновляемая версия.  По умолчанию она
# определяется командой repotools -version, выполняемой с прежним приложением.
# Значение по умолчанию:
# 	<нет>
# Ограничения:
#  - необходимо указать полную строку версии
#    например: 5.0.0 или 5.0.1
#
OLD_APPLICATION_VERSION=

# Параметр: -updateAppServerFiles
# Формат: -updateAppServerFiles <yes | no>
# Описание:
# 	Следует ли обновлять файлы конфигурации сервера приложений по умолчанию (WebSphere Liberty).
# Значение по умолчанию:
# 	yes
# Ограничения:
#  - Допустимы только значения 'yes' и 'no'
#
UPDATE_APPSERVER_FILES=yes

# Параметр: -updateTomcatFiles
# Формат: -updateTomcatFiles <yes | no>
# Описание:
# 	Разрешает/запрещает обновление файлов конфигурации Tomcat.
# Значение по умолчанию:
# 	no
# Ограничения:
#  - Допустимы только значения 'yes' и 'no'
#
UPDATE_TOMCAT_FILES=no

# Параметр: -oldApplicationTomcatHome
# Формат: -oldApplicationTomcatHome <путь-к-каталогу>
# Описание:
# 	Полный путь к корневому каталогу Tomcat приложения в старом экземпляре.
# Значение по умолчанию:
# 	<нет>
# Ограничения:
#  - Допустим только при обновлении RM
#  - Должен задавать существующий каталог
#
OLD_TOMCAT_HOME=

# Параметр: -oldJTSTomcatHome
# Формат: -oldJTSTomcatHome <путь-к-каталогу>
# Описание:
# 	Полный путь к корневому каталогу Tomcat JTS в предыдущей версии.
# Значение по умолчанию:
# 	<нет>
# Ограничения:
#  - Допустим только при обновлении RM
#  - Должен задавать существующий каталог
#
OLD_JTS_TOMCAT_HOME=

# Параметр: -newApplicationHome
# Формат: -newApplicationHome <путь-к-каталогу>
# Описание:
# 	Путь к домашнему каталогу приложения в новой версии.
# Значение по умолчанию:
# 	conf
# Ограничения:
#  - Допустим только при обновлении RTC, QM и RM
#  - Если допустим, то является обязательным
#  - <путь-к-каталогу> должен существовать и оканчиваться на 'server/conf',
#    например: /Jazz/IBM/RRC_4.0/JazzTeamServer/server/conf
#
NEW_APPLICATION_HOME="$START_DIR/conf"

# Параметр: -newJTSHome
# Формат: -newJTSHome <путь-к-каталогу>
# Описание:
# 	Полный путь к домашнему каталогу JTS, который будет использовать новый экземпляр.
# Значение по умолчанию:
# 	Домашний каталог нового приложения
# Ограничения:
#  - <путь к каталогу> должен существовать и оканчиваться на 'server/conf'
#
NEW_JTS_HOME=

# Параметр: -newJTSContextRoot
# Формат: -newJTSContextRoot <корневой-контекст>
# Описание:
# 	Корневой контекст сервера JTS новой версии.
# Значение по умолчанию:
# 	jts
# Ограничения:
#  - <корневой-контекст> должен быть коротким именем каталога (без начальной косой черты)
#
JTS_CONTEXT_ROOT=jts

# Параметр: -newApplicationTomcatHome
# Формат: -newApplicationTomcatHome <путь-к-каталогу>
# Описание:
# 	Путь к корневому каталогу Tomcat приложения в новой версии.
# Значение по умолчанию:
# 	<нет>
#
NEW_TOMCAT_HOME=

# Параметр: -newJTSTomcatHome
# Формат: -newJTSTomcatHome <путь-к-каталогу>
# Описание:
# 	Путь к корневому каталогу Tomcat JTS в новой версии.
# Значение по умолчанию:
# 	<нет>
#
NEW_JTS_TOMCAT_HOME=

# Параметр: -overwrite
# Формат: -overwrite
# Описание:
# 	Принудительная замена (всегда использовать overwrite=yes) при выполнении команд repotools
# Значение по умолчанию:
# 	<нет>
# Ограничения:
#  - Допустимо только пустое значение и значение 'overwrite=yes'
#
# OVERWRITE=overwrite=yes
OVERWRITE=

# Параметр: -noVerify
# Формат: -noVerify
# Описание:
# 	Не выполнять никаких проверок (всегда использовать noVerify) при выполнении команд repotools
# Значение по умолчанию:
# 	<нет>
# Ограничения:
#  - Допустимо только значение 'noVerify' и пустое значение
#
# NO_VERIFY=noVerify
NO_VERIFY=

# Параметр: -noStepPrompt
# Формат: -noStepPrompt
# Описание:
# 	Не выводить запрос перед каждым этапом обновления
# Значение по умолчанию:
# 	false
# Ограничения:
#  - Допустимы только значения 'true' и 'false'
#
# NO_STEP_PROMPT=true
NO_STEP_PROMPT=false

# Параметр: -noEditor
# Формат: -noEditor
# Описание:
#   Не открывать редактор для файлов teamserver.properties.
# Значение по умолчанию:
#   false
# Ограничения:
#  - Допустимы значения 'true', 'false' и пустое значение
#
# NO_EDITOR=false
NO_EDITOR=false

# Параметр: -db.jdbc.location
# Формат: -db.jdbc.location <URL-JDBC>
# Описание:
# 	Расположение JDBC для базы данных RM. (Необходимо только для перехода от 4.x к 5.x) 
#
#		Примеры:
#			DB2 		//localhost:50000/RM_DB:user=db2admin;password={password};
#			DB2i 		//hostname;hold statements=true;metadata source=1;user=rmDBuser;password={password};
#			ORACLE		thin:rmDBuser/{password}@//oracleserver.example.com:1521/RM_DB
#			SQLSERVER	//localhost:1433;databaseName=RM_DB;user=rmDBuser;password={password};
#			DERBY		conf/rm/derby/repositoryDB
#
#		ПРИМЕЧАНИЕ:
#			В системах на базе Unix многие символы (такие как |  &  ;  <  >  (  )  $  `  \  "  '  <пробел>  <табуляция>  <новая строка>) 
#			должны экранироваться символом обратной косой черты. 
#		
#			DB2 		//localhost:50000/RM_DB:user=db2admin\;password={password}\;
#			DB2i 		//hostname;hold\ statements=true\;metadata\ source=1\;user=rmDBuser\;password={password}\;
#			ORACLE		thin:rmDBuser/{password}@//oracleserver.example.com:1521/RM_DB
#			SQLSERVER	//localhost:1433\;databaseName=RM_DB\;user=rmDBuser\;password={password}\;
#			DERBY		conf/rm/derby/repositoryDB	
# Значение по умолчанию:
# 	<нет>
# Ограничения:
#  - Применяется только при обновлении RM версии 4.x
#
DB_JDBC_LOCATION_VALUE=

# Параметр: -db.jdbc.password
# Формат: -db.jdbc.password <ПАРОЛЬ-JDBC>
# Описание:
# 	Пароль (открытым текстом или в зашифрованном виде), который применяется в URL JDBC вместо "{password}". 
# Значение по умолчанию:
# 	<нет>
# Ограничения:
#  - Обязательный параметр, если URL JDBC для базы данных RM содержит {password}
#
DB_JDBC_PASSWORD_VALUE=

# Параметр: -db.db2i.schema.name
# Формат: -db.db2i.schema.name <ИМЯ-СХЕМЫ>
# Описание:
# 	Имя схемы БД DB2i.
# Значение по умолчанию:
# 	<нет>
# Ограничения:
#  - Обязательный параметр для базы данных типа DB2i. 
#
DB_DB2I_SCHEMA_NAME_VALUE=

# Параметр: -db.db2.dsn.dbname
# Формат: -db.db2.dsn.dbname <ИМЯ-БД-DSN>
# Описание:
# 	Имя БД DSN DB2Z.
# Значение по умолчанию:
# 	<нет>
# Ограничения:
#  - Обязательный параметр для базы данных типа DB2z. 
#
DB_DB2_DSN_DBNAME_VALUE=

# Параметр: -db.schemaPrefix
# Формат: -db.schemaPrefix <ПРЕФИКС-СХЕМЫ>
# Описание:
# 	Префикс схемы БД. 
# Значение по умолчанию:
# 	<нет>
# Ограничения:
#  - Обязательный параметр для базы данных типа DB2z. 
#
DB_SCHEMA_PREFIX_VALUE=

# Параметр: -oldJTSHome
# Формат: -oldJTSHome <путь-к-каталогу>
# Описание:
# 	Полный путь к домашнему каталогу JTS в предыдущей версии.
# Значение по умолчанию:
# 	<нет>
# Ограничения:
#  - <путь-к-каталогу> должен существовать и оканчиваться на 'server/conf'
#  - допустим только для обновления RM и JTS
#
OLD_JTS_HOME=

# Параметр: -lpaContextRoot
# Формат: -lpaContextRoot <корневой контекст>
# Описание:
# 	Корневой контекст LPA
# Значение по умолчанию:
# 	admin
# Ограничения:
#  - <корневой контекст> должен задавать допустимое краткое имя каталога (без косой черты)
#
LPA_CONTEXT_ROOT=admin

# Параметр: -noResumePrompt
# Формат: -noResumePrompt
# Описание:
#   Не выводить запрос перед возобновлением шага.
# Значение по умолчанию:
#   false
# Ограничения:
#  - Допустимы только значения 'true' и 'false'
#
# NO_RESUME_PROMPT=false
NO_RESUME_PROMPT=false
